@@ -9,9 +9,7 @@
 
 	// Language and character set
 	$lang['applang'] = 'English';
-	$lang['appcharset'] = 'ISO-8859-1';
-	$lang['applocale'] = 'en_US';
-	$lang['appdbencoding'] = 'LATIN1';
+	$lang['applocale'] = 'en-US';
 	$lang['applangdir'] = 'ltr';
 
 	// Welcome
@@ -22,7 +20,7 @@
 	$lang['strlocaldocs'] = 'PostgreSQL Documentation (local)';
 	$lang['strreportbug'] = 'Report a Bug';
 	$lang['strviewfaq'] = 'View online FAQ';
-	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
+	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
 	
 	// Basic strings
 	$lang['strlogin'] = 'Login';
@@ -150,6 +148,7 @@
 	$lang['strstop'] = 'Stop';
 	$lang['strgotoppage'] = 'back to top';
 	$lang['strtheme'] = 'Theme';
+	$lang['strcluster'] = 'Cluster';
 	
 	// Admin
 	$lang['stradminondatabase'] = 'The following administrative tasks apply on the whole %s database.';
@@ -187,7 +186,6 @@
 	$lang['strnodata'] = 'No rows found.';
 	$lang['strnoobjects'] = 'No objects found.';
 	$lang['strrownotunique'] = 'No unique identifier for this row.';
-	$lang['strnoreportsdb'] = 'You have not created the reports database. Read the INSTALL file for directions.';
 	$lang['strnouploads'] = 'File uploads are disabled.';
 	$lang['strimporterror'] = 'Import error.';
 	$lang['strimporterror-fileformat'] = 'Import error: Failed to automatically determine the file format.';
@@ -307,6 +305,7 @@
 	// Groups
 	$lang['strgroup'] = 'Group';
 	$lang['strgroups'] = 'Groups';
+	$lang['strgroupgroups'] = 'Groups in group "%s"';
 	$lang['strshowallgroups'] = 'Show all groups';
 	$lang['strnogroup'] = 'Group not found.';
 	$lang['strnogroups'] = 'No groups found.';
@@ -661,18 +660,6 @@
 	$lang['strspecifyschematodrop'] = 'You must specify at least one schema to drop.';
 
 	// Reports
-	$lang['strreport'] = 'Report';
-	$lang['strreports'] = 'Reports';
-	$lang['strshowallreports'] = 'Show all reports';
-	$lang['strnoreports'] = 'No reports found.';
-	$lang['strcreatereport'] = 'Create report';
-	$lang['strreportdropped'] = 'Report dropped.';
-	$lang['strreportdroppedbad'] = 'Report drop failed.';
-	$lang['strconfdropreport'] = 'Are you sure you want to drop the report "%s"?';
-	$lang['strreportneedsname'] = 'You must give a name for your report.';
-	$lang['strreportneedsdef'] = 'You must give SQL for your report.';
-	$lang['strreportcreated'] = 'Report saved.';
-	$lang['strreportcreatedbad'] = 'Failed to save report.';
 
 	// Domains
 	$lang['strdomain'] = 'Domain';
@@ -805,118 +792,6 @@
 	$lang['strtablespacealtered'] = 'Tablespace altered.';
 	$lang['strtablespacealteredbad'] = 'Tablespace alteration failed.';
 
-	// Slony clusters
-	$lang['strcluster'] = 'Cluster';
-	$lang['strnoclusters'] = 'No clusters found.';
-	$lang['strconfdropcluster'] = 'Are you sure you want to drop cluster "%s"?';
-	$lang['strclusterdropped'] = 'Cluster dropped.';
-	$lang['strclusterdroppedbad'] = 'Cluster drop failed.';
-	$lang['strinitcluster'] = 'Initialize cluster';
-	$lang['strclustercreated'] = 'Cluster initialized.';
-	$lang['strclustercreatedbad'] = 'Cluster initialization failed.';
-	$lang['strclusterneedsname'] = 'You must give a name for the cluster.';
-	$lang['strclusterneedsnodeid'] = 'You must give an ID for the local node.';
-
-	// Slony nodes
-	$lang['strnodes'] = 'Nodes';
-	$lang['strnonodes'] = 'No nodes found.';
-	$lang['strcreatenode'] = 'Create node';
-	$lang['strid'] = 'ID';
-	$lang['stractive'] = 'Active';
-	$lang['strnodecreated'] = 'Node created.';
-	$lang['strnodecreatedbad'] = 'Node creation failed.';
-	$lang['strconfdropnode'] = 'Are you sure you want to drop node "%s"?';
-	$lang['strnodedropped'] = 'Node dropped.';
-	$lang['strnodedroppedbad'] = 'Node drop failed.';
-	$lang['strfailover'] = 'Failover';
-	$lang['strnodefailedover'] = 'Node failed over.';
-	$lang['strnodefailedoverbad'] = 'Node failover failed.';
-	$lang['strstatus'] = 'Status';	
-	$lang['strhealthy'] = 'Healthy';
-	$lang['stroutofsync'] = 'Out of sync';
-	$lang['strunknown'] = 'Unknown';	
-
-	// Slony paths	
-	$lang['strpaths'] = 'Paths';
-	$lang['strnopaths'] = 'No paths found.';
-	$lang['strcreatepath'] = 'Create path';
-	$lang['strnodename'] = 'Node name';
-	$lang['strnodeid'] = 'Node ID';
-	$lang['strconninfo'] = 'Connection string';
-	$lang['strconnretry'] = 'Seconds before retry to connect';
-	$lang['strpathneedsconninfo'] = 'You must give a connection string for the path.';
-	$lang['strpathneedsconnretry'] = 'You must give the number of seconds to wait before retry to connect.';
-	$lang['strpathcreated'] = 'Path created.';
-	$lang['strpathcreatedbad'] = 'Path creation failed.';
-	$lang['strconfdroppath'] = 'Are you sure you want to drop path "%s"?';
-	$lang['strpathdropped'] = 'Path dropped.';
-	$lang['strpathdroppedbad'] = 'Path drop failed.';
-
-	// Slony listens
-	$lang['strlistens'] = 'Listens';
-	$lang['strnolistens'] = 'No listens found.';
-	$lang['strcreatelisten'] = 'Create listen';
-	$lang['strlistencreated'] = 'Listen created.';
-	$lang['strlistencreatedbad'] = 'Listen creation failed.';
-	$lang['strconfdroplisten'] = 'Are you sure you want to drop listen "%s"?';
-	$lang['strlistendropped'] = 'Listen dropped.';
-	$lang['strlistendroppedbad'] = 'Listen drop failed.';
-
-	// Slony replication sets
-	$lang['strrepsets'] = 'Replication sets';
-	$lang['strnorepsets'] = 'No replication sets found.';
-	$lang['strcreaterepset'] = 'Create replication set';
-	$lang['strrepsetcreated'] = 'Replication set created.';
-	$lang['strrepsetcreatedbad'] = 'Replication set creation failed.';
-	$lang['strconfdroprepset'] = 'Are you sure you want to drop replication set "%s"?';
-	$lang['strrepsetdropped'] = 'Replication set dropped.';
-	$lang['strrepsetdroppedbad'] = 'Replication set drop failed.';
-	$lang['strmerge'] = 'Merge';
-	$lang['strmergeinto'] = 'Merge into';
-	$lang['strrepsetmerged'] = 'Replication sets merged.';
-	$lang['strrepsetmergedbad'] = 'Replication sets merge failed.';
-	$lang['strmove'] = 'Move';
-	$lang['strneworigin'] = 'New origin';
-	$lang['strrepsetmoved'] = 'Replication set moved.';
-	$lang['strrepsetmovedbad'] = 'Replication set move failed.';
-	$lang['strnewrepset'] = 'New replication set';
-	$lang['strlock'] = 'Lock';
-	$lang['strlocked'] = 'Locked';
-	$lang['strunlock'] = 'Unlock';
-	$lang['strconflockrepset'] = 'Are you sure you want to lock replication set "%s"?';
-	$lang['strrepsetlocked'] = 'Replication set locked.';
-	$lang['strrepsetlockedbad'] = 'Replication set lock failed.';
-	$lang['strconfunlockrepset'] = 'Are you sure you want to unlock replication set "%s"?';
-	$lang['strrepsetunlocked'] = 'Replication set unlocked.';
-	$lang['strrepsetunlockedbad'] = 'Replication set unlock failed.';
-	$lang['stronlyonnode'] = 'Only on node';
-	$lang['strddlscript'] = 'DDL script';
-	$lang['strscriptneedsbody'] = 'You must supply a script to be executed on all nodes.';
-	$lang['strscriptexecuted'] = 'Replication set DDL script executed.';
-	$lang['strscriptexecutedbad'] = 'Failed executing replication set DDL script.';
-	$lang['strtabletriggerstoretain'] = 'The following triggers will NOT be disabled by Slony:';
-
-	// Slony tables in replication sets
-	$lang['straddtable'] = 'Add table';
-	$lang['strtableneedsuniquekey'] = 'Table to be added requires a primary or unique key.';
-	$lang['strtableaddedtorepset'] = 'Table added to replication set.';
-	$lang['strtableaddedtorepsetbad'] = 'Failed adding table to replication set.';
-	$lang['strconfremovetablefromrepset'] = 'Are you sure you want to drop the table "%s" from replication set "%s"?';
-	$lang['strtableremovedfromrepset'] = 'Table dropped from replication set.';
-	$lang['strtableremovedfromrepsetbad'] = 'Failed to drop table from replication set.';
-
-	// Slony sequences in replication sets
-	$lang['straddsequence'] = 'Add sequence';
-	$lang['strsequenceaddedtorepset'] = 'Sequence added to replication set.';
-	$lang['strsequenceaddedtorepsetbad'] = 'Failed adding sequence to replication set.';
-	$lang['strconfremovesequencefromrepset'] = 'Are you sure you want to drop the sequence "%s" from replication set "%s"?';
-	$lang['strsequenceremovedfromrepset'] = 'Sequence dropped from replication set.';
-	$lang['strsequenceremovedfromrepsetbad'] = 'Failed to drop sequence from replication set.';
-
-	// Slony subscriptions
-	$lang['strsubscriptions'] = 'Subscriptions';
-	$lang['strnosubscriptions'] = 'No subscriptions found.';
-
 	// Miscellaneous
 	$lang['strtopbar'] = '%s running on %s:%s -- You are logged in as user "%s"';
 	$lang['strtimefmt'] = 'jS M, Y g:iA';
@@ -1021,4 +896,9 @@
 	$lang['strftstabdicts'] = 'Dictionaries';
 	$lang['strftstabparsers'] = 'Parsers';
 	$lang['strftscantparsercopy'] = 'Can\'t specify both parser and template during text search configuration creation.';
+
+	//Plugins
+	$lang['strpluginnotfound'] = 'Error: plugin \'%s\' not found. Check if this plugin exists in the plugins/ directory, or if this plugins has a plugin.php file. Plugin\'s names are case sensitive';
+	$lang['stractionnotfound'] = 'Error: action \'%s\' not found in the \'%s\' plugin, or it was not specified as an action.';
+	$lang['strhooknotfound'] = 'Error: hook \'%s\' is not avaliable.';
 ?>
